/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.user.organisationseinheit;

import static org.assertj.core.api.Assertions.*;

import de.ozgcloud.user.TestDatabaseUtils;
import jakarta.inject.Inject;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;

import com.mongodb.client.MongoClient;

import de.ozgcloud.user.UserTestFactory;
import de.ozgcloud.user.common.MongoDbTestProfile;
import io.quarkus.test.junit.QuarkusTest;
import io.quarkus.test.junit.TestProfile;

@QuarkusTest
@TestProfile(MongoDbTestProfile.class)
class OrganisationsEinheitRepositoryITCase {

	@Inject
	OrganisationsEinheitRepository repository;

	@Inject
	MongoClient mongoClient;

	@Nested
	@DisplayName("Test finding all Organisationseinheiten IDs")
	class TestFindAllOrganisationsEinheitIds {

		@BeforeEach
		void init() {
			var mongoDb = TestDatabaseUtils.getDatabase(mongoClient);
			mongoDb.getCollection("User").drop();
		}

		@Test
		void shouldNotLoadDeletedUser() {
			repository.persist(UserTestFactory.createBuilder().deleted(true).build());

			var result = repository.findAllOrganisationsEinheitIds();

			assertThat(result).isEmpty();
		}

		@Test
		void shouldLoadDistinct() {
			repository.persist(UserTestFactory.create());
			repository.persist(UserTestFactory.createBuilder().id(null).build());

			var result = repository.findAllOrganisationsEinheitIds();

			assertThat(result)
					.hasSize(1)
					.containsExactlyInAnyOrder(UserTestFactory.ORGANISTATIONSEINHEITEN_ID);
		}
	}

}