/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.user.settings;

import static org.assertj.core.api.Assertions.*;

import jakarta.inject.Inject;

import org.bson.types.ObjectId;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;

import de.ozgcloud.user.UserTestFactory;
import de.ozgcloud.user.common.MongoDbTestProfile;
import io.quarkus.test.junit.QuarkusTest;
import io.quarkus.test.junit.TestProfile;

@QuarkusTest
@TestProfile(MongoDbTestProfile.class)
class UserSettingsRepositoryITCase {

	@Inject
	UserSettingsRepository repository;

	@Nested
	class TestUpdateByUserId {

		@BeforeEach
		void beforeEach() {
			repository.deleteAll();
		}

		@Test
		void shouldUpdateUserSettings() {
			var user = UserTestFactory.create();
			repository.persist(user);

			var settings = repository.updateByUserId(
					user.getId().toString(),
					UserSettings.builder().notificationsSendFor(NotificationsSendFor.ALL).build());

			assertThat(settings)
					.isPresent()
					.map(UserSettings::getNotificationsSendFor)
					.hasValue(NotificationsSendFor.ALL);
		}

		@Test
		void shouldReturnEmptyIfUserNotExist() {
			var user = UserTestFactory.create();
			repository.persist(user);

			var settings = repository.updateByUserId(
					new ObjectId().toString(),
					UserSettings.builder().notificationsSendFor(NotificationsSendFor.ALL).build());

			assertThat(settings).isEmpty();
		}

		@Test
		void shouldReturnEmptyIfInvalidUserId() {
			var user = UserTestFactory.create();
			repository.persist(user);

			var settings = repository.updateByUserId(
					"wrong_id",
					UserSettings.builder().notificationsSendFor(NotificationsSendFor.ALL).build());

			assertThat(settings).isEmpty();
		}

		@Test
		void shouldReturnEmptyIfUserIdNull() {
			var user = UserTestFactory.create();
			repository.persist(user);

			var settings = repository.updateByUserId(
					null,
					UserSettings.builder().notificationsSendFor(NotificationsSendFor.ALL).build());

			assertThat(settings).isEmpty();
		}
	}

}