/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.user.settings;

import static org.assertj.core.api.Assertions.*;

import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;

class UserSettingsTest {

	@Nested
	class TestConstructor {
		@Test
		void shouldCreateWithVorgangCreatedSet() {
			var userSettings = new UserSettings(NotificationsSendFor.ALL);

			assertThat(userSettings.isVorgangCreated()).isTrue();
		}

		@Test
		void shouldCreateWithVorgangCreatedUnset() {
			var userSettings = new UserSettings(NotificationsSendFor.NONE);

			assertThat(userSettings.isVorgangCreated()).isFalse();
		}

		@Test
		void shouldCreateWithDefaultValues() {
			var userSettings = new UserSettings();

			assertThat(userSettings).usingRecursiveComparison().isEqualTo(UserSettings.createDefault());
		}
	}

	@Nested
	class TestCreateDefault {

		@Test
		void shouldHaveDefaultSettings() {
			assertThat(UserSettings.createDefault()).usingRecursiveComparison().isEqualTo(
					UserSettings.builder().notificationsSendFor(NotificationsSendFor.NONE).vorgangCreated(false).vorgangAssignedToUser(true)
							.postfachNachrichtFromAntragsteller(true).wiedervorlageDueToday(true).build());
		}

	}
}